==> knews-0.9.3.tar.gz: knews-0.9.3/Widgets/Toggle.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef _Toggle_h
#define _Toggle_h

#ifndef XtCToggleSize
#define XtCToggleSize "ToggleSize"
#endif
#ifndef XtCToggleOffset
#define XtCToggleOffset "ToggleOffset"
#endif
#ifndef XtCSet
#define XtCSet "Set"
#endif

#ifndef XtNtoggleSize
#define XtNtoggleSize "toggleSize"
#endif
#ifndef XtNtoggleOffset
#define XtNtoggleOffset "toggleOffset"
#endif
#ifndef XtNtoggleShadowWidth
#define XtNtoggleShadowWidth "toggleShadowWidth"
#endif
#ifndef XtNset
#define XtNset "set"
#endif

typedef struct _ToggleClassRec*	ToggleWidgetClass;
typedef struct _ToggleRec*	ToggleWidget;

extern WidgetClass toggleWidgetClass;

#ifdef _XFUNCPROTOBEGIN
_XFUNCPROTOBEGIN
#endif

extern void ToggleSet(Widget);
extern void ToggleUnset(Widget);
extern Boolean ToggleGet(Widget);

#ifdef _XFUNCPROTOBEGIN
_XFUNCPROTOEND
#endif

#endif /* _Toggle_h */

==> knews-0.9.6-4.tar.gz: knews-0.9.6/Widgets/Toggle.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef Toggle_h
#define Toggle_h

#ifndef XtCToggleSize
#define XtCToggleSize "ToggleSize"
#endif
#ifndef XtCToggleOffset
#define XtCToggleOffset "ToggleOffset"
#endif
#ifndef XtCSet
#define XtCSet "Set"
#endif

#ifndef XtNtoggleSize
#define XtNtoggleSize "toggleSize"
#endif
#ifndef XtNtoggleOffset
#define XtNtoggleOffset "toggleOffset"
#endif
#ifndef XtNtoggleShadowWidth
#define XtNtoggleShadowWidth "toggleShadowWidth"
#endif
#ifndef XtNset
#define XtNset "set"
#endif

typedef struct ToggleClassRec*	ToggleWidgetClass;
typedef struct ToggleRec*	ToggleWidget;

extern WidgetClass toggleWidgetClass;

#ifdef _XFUNCPROTOBEGIN
_XFUNCPROTOBEGIN
#endif

extern void    ToggleSet(Widget);
extern void    ToggleUnset(Widget);
extern Boolean ToggleGet(Widget);

#ifdef _XFUNCPROTOBEGIN
_XFUNCPROTOEND
#endif

#endif /* Toggle_h */
